CREATE DATABASE B69
GO

USE B69
GO
-----------------------------------------------------------------
----------------------tabele-------------------------------------
-----------------------------------------------------------------
CREATE TABLE dbo.Kategorie
(
	id_kategoria int NOT NULL,
	Nazwa varchar (30) NOT NULL,
)
GO

CREATE TABLE dbo.Pracownicy
(
	id_pracownika int NOT NULL,
	Imie varchar (20) NOT NULL,
	Nazwisko varchar (30) NOT NULL,
	PESEL varchar (11) NOT NULL,
	id_adresu int NOT NULL,
)
GO

CREATE TABLE dbo.Adres
(
	id_adresu int NOT NULL,
	Ulica varchar (30) NOT NULL,
	KodPocztowy varchar (6) NOT NULL,
	Miejscowosc varchar (30) NOT NULL,
	Wojewodztwo Varchar (30) NULL,
)
GO

CREATE TABLE dbo.Klienci
(
	id_klienta int NOT NULL,
	Imie varchar (20) NOT NULL,
	Nazwisko varchar (30) NOT NULL,
	id_adresu int NOT NULL,
)
GO

CREATE TABLE dbo.Producent
(
	id_producenta int NOT NULL,
	Nazwa varchar (40) NOT NULL,
)
GO

CREATE TABLE dbo.Towary
(
	id_towaru int NOT NULL,
	id_kategoria int NOT NULL,
	Nazwa varchar (50) NOT NULL,
	Cena int NOT NULL,
	id_producenta int NOT NULL,
)
GO

CREATE TABLE dbo.Zamowienia
(
	id_zamowienia int NOT NULL,
	id_klienta int NOT NULL,
	id_towaru int NOT NULL,
	Ilosc int NOT NULL,
	id_pracownika int NOT NULL,
)
GO


------------------------------------------------------------------
-----------------------klucze glowne------------------------------
------------------------------------------------------------------

ALTER TABLE dbo.Kategorie ADD
	CONSTRAINT PK_Kategorie PRIMARY KEY (id_kategoria) 
GO

ALTER TABLE dbo.Pracownicy ADD
	CONSTRAINT PK_Pracownicy PRIMARY KEY (id_pracownika) 
GO

ALTER TABLE dbo.Adres ADD
	CONSTRAINT PK_Adres PRIMARY KEY (id_adresu) 
GO

ALTER TABLE dbo.Klienci ADD
	CONSTRAINT PK_Klienci PRIMARY KEY (id_klienta) 
GO

ALTER TABLE dbo.Producent ADD
	CONSTRAINT PK_Producent PRIMARY KEY (id_producenta) 
GO

ALTER TABLE dbo.Towary ADD
	CONSTRAINT PK_Towary PRIMARY KEY (id_towaru) 
GO

ALTER TABLE dbo.Zamowienia ADD
	CONSTRAINT PK_Zamowienia PRIMARY KEY (id_zamowienia) 
GO

--------------------------------------------------------------
----------------klucze obce-----------------------------------
--------------------------------------------------------------

ALTER TABLE dbo.Pracownicy ADD
	CONSTRAINT FK_Pracownicy_Adres FOREIGN KEY (id_adresu) REFERENCES dbo.Adres (id_adresu)
GO

ALTER TABLE dbo.Klienci ADD
	CONSTRAINT FK_Klienci_Adres FOREIGN KEY (id_adresu) REFERENCES dbo.Adres (id_adresu)
GO

ALTER TABLE dbo.Zamowienia ADD
	CONSTRAINT FK_Zamowienia_Klienci FOREIGN KEY (id_klienta) REFERENCES dbo.Klienci (id_klienta),
	CONSTRAINT FK_Zamowienia_Pracownicy FOREIGN KEY (id_pracownika) REFERENCES dbo.Pracownicy (id_pracownika),
	CONSTRAINT FK_Zamowienia_Towary FOREIGN KEY (id_towaru) REFERENCES dbo.Towary (id_towaru)
GO

ALTER TABLE dbo.Towary ADD
	CONSTRAINT FK_Towary_Kategorie FOREIGN KEY (id_kategoria) REFERENCES dbo.Kategorie (id_kategoria),
	CONSTRAINT FK_Towary_Producent FOREIGN KEY (id_producenta) REFERENCES dbo.Producent (id_producenta)
GO

--------------------------------------------------------------
---------------------ograniczenia-----------------------------
--------------------------------------------------------------

ALTER TABLE dbo.Pracownicy ADD
	CONSTRAINT CK_Pracownicy_PESEL CHECK (PESEL LIKE '[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]'),
	CONSTRAINT CK_Pracownicy_Imie CHECK (ASCII(SUBSTRING(Imie,1,1)) = ASCII(UPPER(SUBSTRING(Imie,1,1)))),
	CONSTRAINT CK_Pracownicy_Nazwisko CHECK (ASCII(SUBSTRING(Nazwisko,1,1)) = ASCII(UPPER(SUBSTRING(Nazwisko,1,1))))
GO

ALTER TABLE dbo.Adres ADD
	CONSTRAINT CK_Adres_KodPocztowy CHECK (KodPocztowy LIKE '[0-9][0-9][0-9][0-9][0-9]')
GO

ALTER TABLE dbo.Klienci ADD
	CONSTRAINT CK_Klienci_Imie CHECK (ASCII(SUBSTRING(Imie,1,1)) = ASCII(UPPER(SUBSTRING(Imie,1,1)))),
	CONSTRAINT CK_Klienci_Nazwisko CHECK (ASCII(SUBSTRING(Nazwisko,1,1)) = ASCII(UPPER(SUBSTRING(Nazwisko,1,1))))
GO

--------------------------------------------------------------
---------------------unikalnosc kolumn------------------------
--------------------------------------------------------------

ALTER TABLE dbo.Pracownicy ADD
	CONSTRAINT UN_Pracownicy_PESEL UNIQUE (PESEL)
GO

--------------------------------------------------------------
-------------------wartosci domyslne--------------------------
--------------------------------------------------------------

ALTER TABLE dbo.Adres ADD
	CONSTRAINT DF_Adres_Miejscowosc DEFAULT ('Jelenia Gora') FOR Miejscowosc,
	CONSTRAINT DF_Adres_Wojewodztwo DEFAULT ('dolnoslaskie') FOR Wojewodztwo
GO