CREATE DATABASE B69
GO

USE B69
GO
-----------------------------------------------------------------
----------------------tabele-------------------------------------
-----------------------------------------------------------------
CREATE TABLE dbo.Kategorie
(
	id_kategoria int NOT NULL,
	Nazwa varchar (30) NOT NULL,
)
GO

CREATE TABLE dbo.Pracownicy
(
	id_pracownika int NOT NULL,
	Imie varchar (20) NOT NULL,
	Nazwisko varchar (30) NOT NULL,
	PESEL varchar (11) NOT NULL,
	id_adresu int NOT NULL,
)
GO

CREATE TABLE dbo.Adres
(
	id_adresu int NOT NULL,
	Ulica varchar (30) NOT NULL,
	KodPocztowy varchar (6) NOT NULL,
	Miejscowosc varchar (30) NOT NULL,
	Wojewodztwo Varchar (30) NULL,
)
GO

CREATE TABLE dbo.Klienci
(
	id_klienta int NOT NULL,
	Imie varchar (20) NOT NULL,
	Nazwisko varchar (30) NOT NULL,
	id_adresu int NOT NULL,
)
GO

CREATE TABLE dbo.Producent
(
	id_producenta int NOT NULL,
	Nazwa varchar (40) NOT NULL,
)
GO

CREATE TABLE dbo.Towary
(
	id_towaru int NOT NULL,
	id_kategoria int NOT NULL,
	Nazwa varchar (50) NOT NULL,
	Cena int NOT NULL,
	id_producenta int NOT NULL,
)
GO

CREATE TABLE dbo.Zamowienia
(
	id_zamowienia int NOT NULL,
	id_klienta int NOT NULL,
	id_towaru int NOT NULL,
	Ilosc int NOT NULL,
	id_pracownika int NOT NULL,
)
GO


------------------------------------------------------------------
-----------------------klucze glowne------------------------------
------------------------------------------------------------------

ALTER TABLE dbo.Kategorie ADD
	CONSTRAINT PK_Kategorie PRIMARY KEY (id_kategoria) 
GO

ALTER TABLE dbo.Pracownicy ADD
	CONSTRAINT PK_Pracownicy PRIMARY KEY (id_pracownika) 
GO

ALTER TABLE dbo.Adres ADD
	CONSTRAINT PK_Adres PRIMARY KEY (id_adresu) 
GO

ALTER TABLE dbo.Klienci ADD
	CONSTRAINT PK_Klienci PRIMARY KEY (id_klienta) 
GO

ALTER TABLE dbo.Producent ADD
	CONSTRAINT PK_Producent PRIMARY KEY (id_producenta) 
GO

ALTER TABLE dbo.Towary ADD
	CONSTRAINT PK_Towary PRIMARY KEY (id_towaru) 
GO

ALTER TABLE dbo.Zamowienia ADD
	CONSTRAINT PK_Zamowienia PRIMARY KEY (id_zamowienia) 
GO

--------------------------------------------------------------
----------------klucze obce-----------------------------------
--------------------------------------------------------------

ALTER TABLE dbo.Pracownicy ADD
	CONSTRAINT FK_Pracownicy_Adres FOREIGN KEY (id_adresu) REFERENCES dbo.Adres (id_adresu)
GO

ALTER TABLE dbo.Klienci ADD
	CONSTRAINT FK_Klienci_Adres FOREIGN KEY (id_adresu) REFERENCES dbo.Adres (id_adresu)
GO

ALTER TABLE dbo.Zamowienia ADD
	CONSTRAINT FK_Zamowienia_Klienci FOREIGN KEY (id_klienta) REFERENCES dbo.Klienci (id_klienta),
	CONSTRAINT FK_Zamowienia_Pracownicy FOREIGN KEY (id_pracownika) REFERENCES dbo.Pracownicy (id_pracownika),
	CONSTRAINT FK_Zamowienia_Towary FOREIGN KEY (id_towaru) REFERENCES dbo.Towary (id_towaru)
GO

ALTER TABLE dbo.Towary ADD
	CONSTRAINT FK_Towary_Kategorie FOREIGN KEY (id_kategoria) REFERENCES dbo.Kategorie (id_kategoria),
	CONSTRAINT FK_Towary_Producent FOREIGN KEY (id_producenta) REFERENCES dbo.Producent (id_producenta)
GO

--------------------------------------------------------------
---------------------ograniczenia-----------------------------
--------------------------------------------------------------

ALTER TABLE dbo.Pracownicy ADD
	CONSTRAINT CK_Pracownicy_PESEL CHECK (PESEL LIKE '[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]'),
	CONSTRAINT CK_Pracownicy_Imie CHECK (ASCII(SUBSTRING(Imie,1,1)) = ASCII(UPPER(SUBSTRING(Imie,1,1)))),
	CONSTRAINT CK_Pracownicy_Nazwisko CHECK (ASCII(SUBSTRING(Nazwisko,1,1)) = ASCII(UPPER(SUBSTRING(Nazwisko,1,1))))
GO

ALTER TABLE dbo.Adres ADD
	CONSTRAINT CK_Adres_KodPocztowy CHECK (KodPocztowy LIKE '[0-9][0-9][0-9][0-9][0-9]')
GO

ALTER TABLE dbo.Klienci ADD
	CONSTRAINT CK_Klienci_Imie CHECK (ASCII(SUBSTRING(Imie,1,1)) = ASCII(UPPER(SUBSTRING(Imie,1,1)))),
	CONSTRAINT CK_Klienci_Nazwisko CHECK (ASCII(SUBSTRING(Nazwisko,1,1)) = ASCII(UPPER(SUBSTRING(Nazwisko,1,1))))
GO

--------------------------------------------------------------
---------------------unikalnosc kolumn------------------------
--------------------------------------------------------------

ALTER TABLE dbo.Pracownicy ADD
	CONSTRAINT UN_Pracownicy_PESEL UNIQUE (PESEL)
GO

--------------------------------------------------------------
-------------------wartosci domyslne--------------------------
--------------------------------------------------------------

ALTER TABLE dbo.Adres ADD
	CONSTRAINT DF_Adres_Miejscowosc DEFAULT ('Jelenia Gora') FOR Miejscowosc,
	CONSTRAINT DF_Adres_Wojewodztwo DEFAULT ('dolnoslaskie') FOR Wojewodztwo
GO


--------------------------------------------------------------------------------------------------------------
-------------------------------------------------------P3-----------------------------------------------------
--------------------------------------------------------------------------------------------------------------



-----------------------------------
-- Procedury wstawiajce wiersze --
-----------------------------------

-----------------------------------
----------Adres--------------------
-----------------------------------

CREATE PROCEDURE dbo.Adres_dodaj
@Par_id_adresu int,
@Par_Ulica varchar(20),
@Par_KodPocztowy varchar(6),
@Par_Miejscowosc varchar(30),
@Par_Wojewodztwo varchar(30)
AS
BEGIN
INSERT dbo.Adres
(id_adresu, Ulica, KodPocztowy, Miejscowosc, Wojewodztwo)
VALUES
(@Par_id_adresu, @Par_Ulica, @Par_KodPocztowy, @Par_Miejscowosc, @Par_Wojewodztwo)
END
GO

EXECUTE dbo.Adres_dodaj 1, 'Nowa', '56123', 'Jelenia Gora', 'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 2, 'Stara', '45678', 'Jelenia Gora', 'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 3, 'Krotka', '45966', 'Jelenia Gora', 'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 4, 'Dluga', '36987', 'Jelenia Gora', 'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 5, 'Polna', '12001', 'Bolkow', 'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 6, 'Rynek', '78325', 'Kamienna Gora', 'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 7, 'Boczna', '56369', 'Lubawka', 'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 8, 'Poprzeczna', '67981', 'Jawor', 'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 9, 'Niepodleglosci', '49952', 'Legnica',  'donoslaskie'
GO
EXECUTE dbo.Adres_dodaj 10, 'Wroclawska', '13314', 'Warszawa', 'malopolskie'
GO


------------------------------------
-----------Pracownicy---------------
------------------------------------

CREATE PROCEDURE dbo.Pracownicy_dodaj
@Par_id_pracownika int,
@Par_Imie varchar(20),
@Par_Nazwisko varchar(30),
@Par_PESEL varchar(11),
@Par_id_adresu int
AS
BEGIN
INSERT dbo.Pracownicy
(id_pracownika, Imie, Nazwisko, PESEL, id_adresu)
VALUES
(@Par_id_pracownika, @Par_Imie, @Par_Nazwisko, @Par_PESEL, @Par_id_adresu)
END
GO

EXECUTE dbo.Pracownicy_dodaj 1, 'Marek', 'Borowski', '75060235987', '1'
GO
EXECUTE dbo.Pracownicy_dodaj 2, 'Waldemar', 'Pawlak', '70080812568', '5'
GO
EXECUTE dbo.Pracownicy_dodaj 3, 'Jolanta', 'Kwaniewska', '81120189566', '2'
GO


------------------------------------
--------------Klienci---------------
------------------------------------

CREATE PROCEDURE dbo.Klienci_dodaj
@Par_id_klienta int,
@Par_Imie varchar(20),
@Par_Nazwisko varchar(30),
@Par_id_adresu int
AS
BEGIN
INSERT dbo.Klienci
(id_klienta, Imie, Nazwisko, id_adresu)
VALUES
(@Par_id_klienta, @Par_Imie, @Par_Nazwisko, @Par_id_adresu)
END
GO

EXECUTE dbo.Klienci_dodaj 1, 'Adam', 'Nowak', '1'
GO
EXECUTE dbo.Klienci_dodaj 2, 'Jan', 'Kowalski', '1'
GO
EXECUTE dbo.Klienci_dodaj 3, 'Jolanta', 'Dec', '2'
GO
EXECUTE dbo.Klienci_dodaj 4, 'Jacek', 'Wiernik', '1'
GO
EXECUTE dbo.Klienci_dodaj 5, 'Stefan', 'Kowalewski', '3'
GO
EXECUTE dbo.Klienci_dodaj 6, 'Zbigniew', 'Malecki', '2'
GO
EXECUTE dbo.Klienci_dodaj 7, 'Mieczyslaw', 'Fog', '2'
GO
EXECUTE dbo.Klienci_dodaj 8, 'Artur', 'Niewiadomski', '1'
GO
EXECUTE dbo.Klienci_dodaj 9, 'Arkadiusz', 'Jakubowicz', '4'
GO
EXECUTE dbo.Klienci_dodaj 10, 'Mariola', 'Malinowska', '2'
GO


------------------------------------
--------------Kategorie-------------
------------------------------------

CREATE PROCEDURE dbo.Kategorie_dodaj
@Par_id_kategoria int,
@Par_Nazwa varchar(30)
AS
BEGIN
INSERT dbo.Kategorie
(id_kategoria, Nazwa)
VALUES
(@Par_id_kategoria, @Par_Nazwa)
END
GO

EXECUTE dbo.Kategorie_dodaj 1, 'Zestaw komputerowy'
GO
EXECUTE dbo.Kategorie_dodaj 2, 'Laptop'
GO
EXECUTE dbo.Kategorie_dodaj 3, 'Monitory'
GO
EXECUTE dbo.Kategorie_dodaj 4, 'Drukarki'
GO
EXECUTE dbo.Kategorie_dodaj 5, 'Podzespoy'
GO
EXECUTE dbo.Kategorie_dodaj 6, 'Akcesoria'
GO
EXECUTE dbo.Kategorie_dodaj 7, 'Inne'
GO

------------------------------------
--------------Producent-------------
------------------------------------

CREATE PROCEDURE dbo.Producent_dodaj
@Par_id_producenta int,
@Par_Nazwa varchar(30)
AS
BEGIN
INSERT dbo.Producent
(id_producenta, Nazwa)
VALUES
(@Par_id_producenta, @Par_Nazwa)
END
GO

EXECUTE dbo.Producent_dodaj 1, 'IBM'
GO
EXECUTE dbo.Producent_dodaj 2, 'INTEL'
GO
EXECUTE dbo.Producent_dodaj 3, 'APPLE'
GO
EXECUTE dbo.Producent_dodaj 4, 'HP'
GO
EXECUTE dbo.Producent_dodaj 5, 'LG'
GO
EXECUTE dbo.Producent_dodaj 6, 'AMD'
GO
EXECUTE dbo.Producent_dodaj 7, 'ASUS'
GO
EXECUTE dbo.Producent_dodaj 8, 'TOSHIBA'
GO
EXECUTE dbo.Producent_dodaj 9, 'CANON'
GO
EXECUTE dbo.Producent_dodaj 10, 'EPSON'
GO


------------------------------------
-----------Towary-------------------
------------------------------------

CREATE PROCEDURE dbo.Towary_dodaj
@Par_id_towaru int,
@Par_id_kategoria int,
@Par_Nazwa varchar(50),
@Par_Cena int,
@Par_id_producenta int
AS
BEGIN
INSERT dbo.Towary
(id_towaru, id_kategoria, Nazwa, Cena, id_producenta)
VALUES
(@Par_id_towaru, @Par_id_kategoria, @Par_Nazwa, @Par_Cena, @Par_id_producenta)
END
GO

EXECUTE dbo.Towary_dodaj 1, '1', 'Uniwersalny', '1700', '1'
GO
EXECUTE dbo.Towary_dodaj 2, '1', 'Dla gracza', '2000', '1'
GO
EXECUTE dbo.Towary_dodaj 3, '2', 'X50GL-AP158 T3200', '2547', '7'
GO
EXECUTE dbo.Towary_dodaj 4, '2', 'Pavilion dv5-1040ew', '2316', '4'
GO
EXECUTE dbo.Towary_dodaj 5, '4', 'MP 170', '300', '9'
GO
EXECUTE dbo.Towary_dodaj 6, '4', '3870', '452', '4'
GO
EXECUTE dbo.Towary_dodaj 7, '3', 'L1919S', '799', '5'
GO
EXECUTE dbo.Towary_dodaj 8, '3', 'L1717S', '599', '5'
GO
EXECUTE dbo.Towary_dodaj 9, '1', 'Multimedialny', '2365',  '6'
GO
EXECUTE dbo.Towary_dodaj 10, '1', 'Dla wymagajacych', '2999', '6'
GO

------------------------------------
-----------Zamwienia---------------
------------------------------------

CREATE PROCEDURE dbo.Zamowienia_dodaj
@Par_id_zamowienia int,
@Par_id_klienta int,
@Par_id_towaru int,
@Par_Ilosc int,
@Par_id_pracownika int
AS
BEGIN
INSERT dbo.Zamowienia
(id_zamowienia, id_klienta, id_towaru, Ilosc, id_pracownika)
VALUES
(@Par_id_zamowienia, @Par_id_klienta, @Par_id_towaru, @Par_Ilosc, @Par_id_pracownika)
END
GO

EXECUTE dbo.Zamowienia_dodaj 1, '1', '1', '1', '1'
GO
EXECUTE dbo.Zamowienia_dodaj 2, '1', '7', '1', '1'
GO
EXECUTE dbo.Zamowienia_dodaj 3, '2', '5', '1', '1'
GO
EXECUTE dbo.Zamowienia_dodaj 4, '7', '4', '1', '3'
GO
EXECUTE dbo.Zamowienia_dodaj 5, '9', '10', '1', '3'
GO
EXECUTE dbo.Zamowienia_dodaj 6, '4', '9', '1', '3'
GO
EXECUTE dbo.Zamowienia_dodaj 7, '8', '7', '1', '3'
GO
EXECUTE dbo.Zamowienia_dodaj 8, '3', '1', '1', '2'
GO
EXECUTE dbo.Zamowienia_dodaj 9, '10', '8', '1',  '2'
GO
EXECUTE dbo.Zamowienia_dodaj 10, '6', '3', '1', '2'
GO


---------------------------------------------------------
-------------Procedury modyfikujce wiersze--------------
---------------------------------------------------------

-----------------------------------
----------Adres--------------------
-----------------------------------
CREATE PROCEDURE dbo.Adres_zmien
@Par_id_adresu int,
@Par_Ulica varchar(20),
@Par_KodPocztowy varchar(6),
@Par_Miejscowosc varchar(30),
@Par_Wojewodztwo varchar(30)
AS
BEGIN

UPDATE dbo.Adres
SET Ulica = @Par_Ulica, 
KodPocztowy = @Par_KodPocztowy,
Miejscowosc = @Par_Miejscowosc,
Wojewodztwo = @Par_Wojewodztwo

WHERE id_adresu = @Par_id_adresu
END
GO

EXECUTE dbo.Adres_zmien 2,'Nowowiejska', '00999', 'Lubin', 'dolnoslaskie'
GO
EXECUTE dbo.Adres_zmien 3,'Wylotowa', '58500', 'Jelania Gora', 'dolnoslaskie'
GO
EXECUTE dbo.Adres_zmien 10,'Rynek', '55878', 'Warszawa', 'mazowieckie'
GO


------------------------------------
-----------Pracownicy---------------
------------------------------------

CREATE PROCEDURE dbo.Pracownicy_zmien
@Par_id_pracownika int,
@Par_Imie varchar(20),
@Par_Nazwisko varchar(30),
@Par_PESEL varchar(11),
@Par_id_adresu int
AS
BEGIN

UPDATE dbo.Pracownicy
SET Imie = @Par_Imie, 
Nazwisko = @Par_Nazwisko,
PESEL = @Par_PESEL,
id_adresu = @Par_id_adresu

WHERE id_pracownika = @Par_id_pracownika
END
GO

EXECUTE dbo.Pracownicy_zmien 1, 'Marek', 'Borowski', '00000000000', 5
GO
EXECUTE dbo.Pracownicy_zmien 3, 'Jolanta', 'Kwaniewska', '12345678912', 1
GO

------------------------------------
--------------Klienci---------------
------------------------------------

CREATE PROCEDURE dbo.Klienci_zmien
@Par_id_klienta int,
@Par_Imie varchar(20),
@Par_Nazwisko varchar(30),
@Par_id_adresu int
AS
BEGIN

UPDATE dbo.Klienci
SET Imie = @Par_Imie, 
Nazwisko = @Par_Nazwisko,
id_adresu = @Par_id_adresu

WHERE id_klienta = @Par_id_klienta
END
GO


EXECUTE dbo.Klienci_zmien 1, 'Joel', 'Sluczka', 10
GO
EXECUTE dbo.Klienci_zmien 5, 'Barack', 'Obama', 4
GO
EXECUTE dbo.Klienci_zmien 9, 'Bill', 'Clinton', 7
GO

------------------------------------
--------------Kategorie-------------
------------------------------------

CREATE PROCEDURE dbo.Kategorie_zmien
@Par_id_kategoria int,
@Par_Nazwa varchar(30)
AS
BEGIN

UPDATE dbo.Kategorie
SET Nazwa = @Par_Nazwa 

WHERE id_kategoria = @Par_id_kategoria
END
GO

EXECUTE dbo.Kategorie_zmien 3, 'LCD'
GO
EXECUTE dbo.Kategorie_zmien 7, 'Wyposazenie'
GO


------------------------------------
--------------Producent-------------
------------------------------------

CREATE PROCEDURE dbo.Producent_zmien
@Par_id_producenta int,
@Par_Nazwa varchar(30)
AS
BEGIN

UPDATE dbo.Producent
SET Nazwa = @Par_Nazwa 

WHERE id_producenta = @Par_id_producenta
END
GO

EXECUTE dbo.Producent_zmien 7, 'ACER'
GO
EXECUTE dbo.Producent_zmien 10, 'LEXMARK'
GO

------------------------------------
-----------Towary-------------------
------------------------------------

CREATE PROCEDURE dbo.Towary_zmien
@Par_id_towaru int,
@Par_id_kategoria int,
@Par_Nazwa varchar(50),
@Par_Cena int,
@Par_id_producenta int
AS
BEGIN

UPDATE dbo.Towary
SET id_kategoria = @Par_id_kategoria, 
Nazwa = @Par_Nazwa,
Cena = @Par_Cena,
id_producenta = @Par_id_producenta

WHERE id_towaru = @Par_id_towaru
END
GO

EXECUTE dbo.Towary_zmien 1, '1', 'Do wszystkiego', '1799', 6
GO
EXECUTE dbo.Towary_zmien 8, '3', 'AC22P', '1100', 7
GO

------------------------------------
-----------Zamwienia---------------
------------------------------------

CREATE PROCEDURE dbo.Zamowienia_zmien
@Par_id_zamowienia int,
@Par_id_klienta int,
@Par_id_towaru int,
@Par_Ilosc int,
@Par_id_pracownika int
AS
BEGIN

UPDATE dbo.Zamowienia
SET id_klienta = @Par_id_klienta, 
id_towaru = @Par_id_towaru,
Ilosc = @Par_Ilosc,
id_pracownika = @Par_id_pracownika

WHERE id_zamowienia = @Par_id_zamowienia
END
GO

EXECUTE dbo.Zamowienia_zmien 1, 3, 3, '3', 3
GO
EXECUTE dbo.Zamowienia_zmien 9, 9, 9, '9', 3
GO


---------------------------------------------------------
-------------Procedury usuwajace wiersze-----------------
---------------------------------------------------------

------------------------------------
-----------Zamwienia---------------
------------------------------------

CREATE PROCEDURE dbo.Zamowienia_usun
@Par_id_zamowienia int
AS
BEGIN

DELETE dbo.Zamowienia
WHERE id_zamowienia = @Par_id_zamowienia
END
GO

EXECUTE dbo.Zamowienia_usun 1
GO
EXECUTE dbo.Zamowienia_usun 2
GO
EXECUTE dbo.Zamowienia_usun 3
GO

------------------------------------
-----------Towary-------------------
------------------------------------

CREATE PROCEDURE dbo.Towary_usun
@Par_id_towaru int
AS
BEGIN

DELETE dbo.Towary
WHERE id_towaru = @Par_id_towaru
END
GO

EXECUTE dbo.Towary_usun 2
GO
-----------------------------------
----------Adres--------------------
-----------------------------------
CREATE PROCEDURE dbo.Adres_usun
@Par_id_adresu int
AS
BEGIN

DELETE dbo.Adres
WHERE id_adresu = @Par_id_adresu
END
GO

EXECUTE dbo.Adres_usun 3
GO
EXECUTE dbo.Adres_usun 8
GO

------------------------------------
-----------Pracownicy---------------
------------------------------------

CREATE PROCEDURE dbo.Pracownicy_usun
@Par_id_pracownika int
AS
BEGIN

DELETE dbo.Pracownicy
WHERE id_pracownika = @Par_id_pracownika
END
GO

EXECUTE dbo.Pracownicy_usun 1
GO

------------------------------------
--------------Klienci---------------
------------------------------------

CREATE PROCEDURE dbo.Klienci_usun
@Par_id_klienta int
AS
BEGIN

DELETE dbo.Klienci
WHERE id_klienta = @Par_id_klienta
END
GO

EXECUTE dbo.Klienci_usun 1
GO
EXECUTE dbo.Klienci_usun 5
GO

------------------------------------
--------------Kategorie-------------
------------------------------------

CREATE PROCEDURE dbo.Kategorie_usun
@Par_id_kategoria int
AS
BEGIN

DELETE dbo.Kategorie
WHERE id_kategoria = @Par_id_kategoria
END
GO

EXECUTE dbo.Kategorie_usun 5
GO

------------------------------------
--------------Producent-------------
------------------------------------

CREATE PROCEDURE dbo.Producent_usun
@Par_id_producenta int
AS
BEGIN

DELETE dbo.Producent
WHERE id_producenta = @Par_id_producenta
END
GO

EXECUTE dbo.Producent_usun 8
GO


----------------------------------------------------------------------------------------------------
---------------------------------------------------P4-----------------------------------------------
----------------------------------------------------------------------------------------------------

-----------------------------------------------------------
--Procedura zliczajca ilo towarw z wybranej kategorii--
-----------------------------------------------------------

CREATE PROCEDURE towary_zliczanie_kategoria
@Par_id_kategoria int = '', 
@Par_MinTow int = 0 
AS
BEGIN
SELECT id_kategoria, COUNT(*) AS [Liczba towarow]
FROM dbo.Towary
WHERE id_kategoria LIKE ' ' + @Par_id_kategoria + ' '
GROUP BY id_kategoria
HAVING COUNT(*) >= @Par_MinTow  
ORDER BY [Liczba towarow] DESC 
END
GO


-----------------------------------------------------------
-------Procedura wyszukujca klientw wedug nazwiska------
-----------------------------------------------------------

CREATE PROCEDURE klient_szukanie
@Par_Nazwisko varchar(30) = ' ' 
AS
BEGIN 
SELECT id_klienta AS [Numer Klienta], Imie, Nazwisko, id_adresu [Numer Adresu]
FROM B69.dbo.Klienci
WHERE Nazwisko LIKE '%' + @Par_Nazwisko + '%'
ORDER BY Nazwisko ASC
END
GO

----------------------------------------------------------------------
-------Procedura wyszukujca pracownika wedug numeru zamwienia------
----------------------------------------------------------------------

CREATE PROCEDURE Zamowienie_Pracownik_szukanie
@Par_id_zamowienia int = ' '
AS
BEGIN
SELECT Pracownicy.id_pracownika AS [Numer Pracownika], Imie, Nazwisko, id_adresu AS [Numer Adresu]
FROM B69.dbo.Pracownicy INNER JOIN B69.dbo.Zamowienia 
ON B69.dbo.Pracownicy.id_pracownika = B69.dbo.Zamowienia.id_pracownika
WHERE id_zamowienia LIKE ' ' + @Par_id_zamowienia + ' '
END
GO

----------------------------------------------------------------------
-------Procedura wyszukujca producenta wedug nazwy towaru-----------
----------------------------------------------------------------------

CREATE PROCEDURE Towary_Producent_szukanie
@Par_Nazwa varchar(50) = ' '
AS
BEGIN
SELECT Producent.id_producenta AS [Numer Producenta], Producent.Nazwa AS [Nazwa Producenta], Towary.Nazwa AS [Nazwa Towaru]
FROM B69.dbo.Producent INNER JOIN B69.dbo.Towary 
ON B69.dbo.Producent.id_producenta = B69.dbo.Towary.id_producenta
WHERE Towary.Nazwa LIKE '%' + @Par_Nazwa + '%'
ORDER BY Producent.Nazwa ASC
END
GO

--------------------------------------------------------------------------
-------Procedura zliczajca ilo zamwie wybranego pracownika-----------
--------------------------------------------------------------------------

CREATE PROCEDURE pracownik_zamowienia_zliczanie
@Par_id_pracownika int = '', 
@Par_MinZam int = 0 
AS
BEGIN
SELECT id_pracownika [Numer Pracownika], COUNT(*) AS [Liczba Zamowien]
FROM B69.dbo.Zamowienia
WHERE id_pracownika LIKE ' ' + @Par_id_pracownika + ' '
GROUP BY id_pracownika
HAVING COUNT(*) >= @Par_MinZam  
ORDER BY [Liczba Zamowien] DESC 
END
GO

--------------------------------------------------------------------------
-------Procedura wywietlajca ceny towarw w kolejnoci rosncej---------
--------------------------------------------------------------------------

CREATE PROCEDURE cena_min
@Par_Cena int = 0
AS
SELECT  MIN(Cena) AS [Minimalna Cena]
FROM B69.dbo.Towary
GROUP BY Cena 
HAVING MIN(Cena)  >= @Par_Cena
GO


--------------------------------------------------------------------------
-------Procedura szukajca klientw wedug miejsca zamieszkania-----------
--------------------------------------------------------------------------

CREATE PROCEDURE klient_adres
@Par_Miejscowosc varchar(30) = ''
AS
SELECT  Imie, Nazwisko
FROM B69.dbo.Klienci
WHERE id_adresu IN (
	SELECT id_adresu
	FROM B69.dbo.Adres
	WHERE Miejscowosc LIKE '%' + @Par_Miejscowosc + '%')

GO

--------------------------------------------------------------------------
-------Procedura czca dwie kolumny w jedn, w tabeli klienci-----------
--------------------------------------------------------------------------

CREATE PROCEDURE zlaczanie_kolumn
AS
SELECT id_klienta AS [Numer Klienta] ,LTRIM(RTRIM(Imie)) + ' ' + LTRIM(RTRIM(Nazwisko)) + ' '  AS [Klient]
FROM B69.dbo.Klienci
GO